==> cscec5b-fjwz-api-3.0.1-20221213.083836-44-sources.jar: com/ejianc/business/fjwz/vo/AnalysisVO.java <==
package com.ejianc.business.fjwz.vo;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 报表
 * 
 * @author syj
 * 
 */
public class AnalysisVO {
    private static final long serialVersionUID = 1L;

    private BigDecimal projectNum; // 累计使用项目
    private BigDecimal czNum; // 累计处置次数
    private BigDecimal xjNum; // 询价次数
    private BigDecimal moneyNum; // 累计处置总金额
    private String orgName;
    private Date shelfTime;
    private String period;//月份
    private int days;
    private int frequency;//次数

    public int getFrequency() {
        return frequency;
    }

    public void setFrequency(int frequency) {
        this.frequency = frequency;
    }

    public BigDecimal getProjectNum() {
        return projectNum;
    }

    public void setProjectNum(BigDecimal projectNum) {
        this.projectNum = projectNum;
    }

    public BigDecimal getCzNum() {
        return czNum;
    }

    public void setCzNum(BigDecimal czNum) {
        this.czNum = czNum;
    }

    public BigDecimal getXjNum() {
        return xjNum;
    }

    public void setXjNum(BigDecimal xjNum) {
        this.xjNum = xjNum;
    }

    public BigDecimal getMoneyNum() {
        return moneyNum;
    }

    public void setMoneyNum(BigDecimal moneyNum) {
        this.moneyNum = moneyNum;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Date getShelfTime() {
        return shelfTime;
    }

    public void setShelfTime(Date shelfTime) {
        this.shelfTime = shelfTime;
    }

    public String getPeriod() {
        return period;
    }

    public void setPeriod(String period) {
        this.period = period;
    }

    public int getDays() {
        return days;
    }

    public void setDays(int days) {
        this.days = days;
    }
}

==> cscec5b-fjwz-api-3.0.1-20230217.085111-72-sources.jar: com/ejianc/business/fjwz/vo/AnalysisVO.java <==
package com.ejianc.business.fjwz.vo;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 报表
 *
 * @author syj
 *
 */
public class AnalysisVO {
    private static final long serialVersionUID = 1L;

    private BigDecimal projectNum; // 累计使用项目
    private BigDecimal czNum; // 累计处置次数
    private BigDecimal xjNum; // 询价次数
    private BigDecimal moneyNum; // 累计处置总金额
    private BigDecimal realMoneyNum; // 实际处置总金额
    private String orgName;
    private Date shelfTime;
    private String period;//月份
    private int days;
    private int frequency;//次数
    private Long orgId;

    public int getFrequency() {
        return frequency;
    }

    public void setFrequency(int frequency) {
        this.frequency = frequency;
    }

    public BigDecimal getProjectNum() {
        return projectNum;
    }

    public void setProjectNum(BigDecimal projectNum) {
        this.projectNum = projectNum;
    }

    public BigDecimal getCzNum() {
        return czNum;
    }

    public void setCzNum(BigDecimal czNum) {
        this.czNum = czNum;
    }

    public BigDecimal getXjNum() {
        return xjNum;
    }

    public void setXjNum(BigDecimal xjNum) {
        this.xjNum = xjNum;
    }

    public BigDecimal getMoneyNum() {
        return moneyNum;
    }

    public void setMoneyNum(BigDecimal moneyNum) {
        this.moneyNum = moneyNum;
    }

    public BigDecimal getRealMoneyNum() {
        return realMoneyNum;
    }

    public void setRealMoneyNum(BigDecimal realMoneyNum) {
        this.realMoneyNum = realMoneyNum;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Date getShelfTime() {
        return shelfTime;
    }

    public void setShelfTime(Date shelfTime) {
        this.shelfTime = shelfTime;
    }

    public String getPeriod() {
        return period;
    }

    public void setPeriod(String period) {
        this.period = period;
    }

    public int getDays() {
        return days;
    }

    public void setDays(int days) {
        this.days = days;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
}
